==> elki_0.6.0.orig.tar.bz2: elki-0.6.0/src/de/lmu/ifi/dbs/elki/logging/statistics/DoubleStatistic.java <==
package de.lmu.ifi.dbs.elki.logging.statistics;

/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2013
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import de.lmu.ifi.dbs.elki.utilities.FormatUtil;

/**
 * Trivial double-valued statistic.
 * 
 * @author Erich Schubert
 */
public class DoubleStatistic extends AbstractStatistic {
  /**
   * Statistic value.
   */
  double value;

  /**
   * Constructor.
   * 
   * @param key Key
   */
  public DoubleStatistic(String key) {
    super(key);
  }

  /**
   * Constructor.
   * 
   * @param key Key
   * @param value Value
   */
  public DoubleStatistic(String key, double value) {
    super(key);
    this.value = value;
  }

  /**
   * Set the statistics.
   * 
   * @param value New value
   */
  public void setDouble(double value) {
    this.value = value;
  }

  @Override
  public String formatValue() {
    return FormatUtil.NF.format(value);
  }
}

==> elki_0.6.5~20141030.orig.tar.bz2: elki-0.6.5~20141030/src/de/lmu/ifi/dbs/elki/logging/statistics/DoubleStatistic.java <==
package de.lmu.ifi.dbs.elki.logging.statistics;

/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2014
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Trivial double-valued statistic.
 * 
 * @author Erich Schubert
 */
public class DoubleStatistic extends AbstractStatistic {
  /**
   * Statistic value.
   */
  double value;

  /**
   * Constructor.
   * 
   * @param key Key
   */
  public DoubleStatistic(String key) {
    super(key);
  }

  /**
   * Constructor.
   * 
   * @param key Key
   * @param value Value
   */
  public DoubleStatistic(String key, double value) {
    super(key);
    this.value = value;
  }

  /**
   * Set the statistics.
   * 
   * @param value New value
   */
  public void setDouble(double value) {
    this.value = value;
  }

  @Override
  public String formatValue() {
    return Double.toString(value);
  }
}
